%global namedreltag .RELEASE
%global namedversion %{version}%{?namedreltag}
%global oname spring-social-twitter
Name:          springframework-social-twitter
# Newer release require springframework >= 4.0.6.RELEASE
Version:       1.0.5
Release:       4%{?dist}
Summary:       Spring Social Twitter API binding and connect support
License:       ASL 2.0
URL:           http://projects.spring.io/spring-social-twitter/
Source0:       https://github.com/spring-projects/spring-social-twitter/archive/v%{namedversion}.tar.gz
Source1:       http://repo1.maven.org/maven2/org/springframework/social/%{oname}/%{namedversion}/%{oname}-%{namedversion}.pom

BuildRequires: maven-local
BuildRequires: mvn(junit:junit)
BuildRequires: mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires: mvn(org.codehaus.jackson:jackson-mapper-asl)
BuildRequires: mvn(org.hamcrest:hamcrest-library)
BuildRequires: mvn(org.mockito:mockito-core)
BuildRequires: mvn(org.springframework:spring-test)
BuildRequires: mvn(org.springframework.security:spring-security-crypto)
BuildRequires: mvn(org.springframework.social:spring-social-core)
#BuildRequires: mvn(org.testng:testng)

BuildArch:     noarch

%description
Spring Social Twitter is an extension of Spring Social that enables you to
connection your application with Twitter's REST API.

%package javadoc
Summary:       Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q -n %{oname}-%{namedversion}
find . -name "*.bat" -delete
find . -name "*.class" -delete
find . -name "*.jar" -delete

cp -p %{SOURCE1} %{oname}/pom.xml
# This is a dummy POM added just to ease building in the RPM platforms
cat > pom.xml << EOF
<?xml version="1.0" encoding="UTF-8"?>
<project
  xmlns="http://maven.apache.org/POM/4.0.0"
  xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/maven-v4_0_0.xsd"
  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">

  <modelVersion>4.0.0</modelVersion>
  <groupId>org.springframework.social</groupId>
  <artifactId>spring-social</artifactId>
  <version>%{namedversion}</version>
  <packaging>pom</packaging>
  <name>Spring Social</name>
  <modules>
    <module>spring-social-twitter</module>
  </modules>
</project>
EOF

# Add OSGi support
%pom_xpath_inject "pom:project" "<packaging>bundle</packaging>" %{oname}
%pom_add_plugin org.apache.felix:maven-bundle-plugin:2.5.4 %{oname} "
<extensions>true</extensions>
<configuration>
  <instructions>
    <Bundle-SymbolicName>\${project.groupId}.twitter</Bundle-SymbolicName>
    <Bundle-Name>\${project.name}</Bundle-Name>
    <Bundle-Version>\${project.version}</Bundle-Version>
  </instructions>
</configuration>
<executions>
  <execution>
    <id>bundle-manifest</id>
    <phase>process-classes</phase>
    <goals>
      <goal>manifest</goal>
    </goals>
  </execution>
</executions>"

# Add Test deps
%pom_add_dep junit:junit:4.11:test %{oname}
%pom_add_dep org.hamcrest:hamcrest-library:1.3:test %{oname}
%pom_add_dep org.mockito:mockito-core:1.9.5:test %{oname}
%pom_add_dep org.springframework:spring-test:3.1.4.RELEASE:test %{oname}
#%% pom_add_dep org.testng:testng:6.8.21:test %%{oname}

# Copy test resources in default maven location
mkdir -p %{oname}/src/test/resources/org/springframework/social/twitter/api/impl
mv %{oname}/src/test/java/org/springframework/social/twitter/api/impl/*.json \
 %{oname}/src/test/resources/org/springframework/social/twitter/api/impl/
mv %{oname}/src/test/java/org/springframework/social/twitter/api/impl/*.jpg \
 %{oname}/src/test/resources/org/springframework/social/twitter/api/impl/

# Require spring-test-mvc
rm -r %{oname}/src/test/java/org/springframework/social/twitter/api/impl/BlockTemplateTest.java \
 %{oname}/src/test/java/org/springframework/social/twitter/api/impl/AbstractTwitterApiTest.java \
 %{oname}/src/test/java/org/springframework/social/twitter/api/impl/UserTemplateTest.java \
 %{oname}/src/test/java/org/springframework/social/twitter/api/impl/FriendTemplateTest.java \
 %{oname}/src/test/java/org/springframework/social/twitter/api/impl/GeoTemplateTest.java \
 %{oname}/src/test/java/org/springframework/social/twitter/api/impl/ApiErrorTest.java \
 %{oname}/src/test/java/org/springframework/social/twitter/api/impl/ListsTemplateTest.java \
 %{oname}/src/test/java/org/springframework/social/twitter/api/impl/DirectMessageTemplateTest.java \
 %{oname}/src/test/java/org/springframework/social/twitter/api/impl/TimelineTemplateTest.java \
 %{oname}/src/test/java/org/springframework/social/twitter/api/impl/SearchParametersTest.java \
 %{oname}/src/test/java/org/springframework/social/twitter/api/impl/SearchTemplateTest.java
 
sed -i 's/\r//' src/dist/*.txt

%mvn_package :spring-social __noinstall

%build

# Disable test suite incompatibility with newer cglib
# NoClassDefFoundError: Could not initialize class org.mockito.internal.creation.cglib.ClassImposterizer$3
%mvn_build -f -- -Dproject.build.sourceEncoding=UTF-8

%install
%mvn_install

%files -f .mfiles
%doc README src/dist/changelog.txt src/dist/readme.txt
%license LICENSE NOTICE src/dist/license.txt src/dist/notice.txt

%files javadoc -f .mfiles-javadoc
%license LICENSE NOTICE src/dist/license.txt src/dist/notice.txt

%changelog
* Sat Jul 09 2016 gil cattaneo <puntogil@libero.it> 1.0.5-4
- disable test suite

* Mon Jun 20 2016 gil cattaneo <puntogil@libero.it> 1.0.5-3
- add missing build requires: maven-plugin-bundle

* Fri Feb 05 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sun Sep 27 2015 gil cattaneo <puntogil@libero.it> 1.0.5-1
- initial rpm
